<?php
/*
 * IMAGE CMS
 * copyright pixelimage.jp All rights reserved.
 */

if (!defined('IMAGE_CMS')) exit;

/* ! ---------- ImageDirClass ---------- ---------- ---------- ---------- */

class ImageDirClass{
	var $base = "";
	var $main = "";
	var $gloup = "";
	var $mini = "";
	var $orig = "";
	var $json = "";
	
	var $dirs = array();
	var $files = array();

	function init($g){
		$b = false;
		
		$this->gloup = $g;
		$this->base		=  IMAGE_DIR;
	
		if($this->gloup != "") {
			$this->base .= $this->gloup."/";
		} 		
		$this->main		= $this->base;
		$this->mini 	= $this->base."_mini/";
		$this->orig	 	= $this->base."_original/";
		$this->json		= $this->base."_json/";
		
		$this->_hasDir();
	}
	function _hasDir(){
		
		if(is_dir($this->main)){
			$dir = opendir($this->main);
			if($this->gloup != ""){
				$this->createSubDir($this->mini);
				$this->createSubDir($this->orig);
				$this->createSubDir($this->json);
			}
		} else{
			status_error("can not open directory.");
		}
		
	}

	/* ! ---------- createSubDir ---------- ---------- ---------- ---------- */
	function createSubDir($_dir){
		if(!file_exists($_dir)){
			if(! mkdir($_dir)){
				status_error("failed to create sub directory.");
			} else{
				chmod($_dir,0707);
			}
		}
	}
	/* ! ---------- createDir ---------- ---------- ---------- ---------- */
	function createDir($dir_name){
		if(!file_exists($this->main.$dir_name)){
			if(! mkdir($this->main.$dir_name)){
				status_error("failed to create new directory.");
			} else{
				chmod($this->main.$dir_name,0707);
			}
		} else{
			status_error("code_005");
		}
	}
	
	/* ! ---------- renameDir ---------- ---------- ---------- ---------- */
	function renameDir($dir_name,$dir_rename){
		checkFileExist($this->main.$dir_name);
		if(! rename(
				$this->main.$dir_name,
				$this->main.$dir_rename
		)){
			status_error("failed to rename directory.");
		}
	}
	/* ! ---------- deleteDir ---------- ---------- ---------- ---------- */
	function deleteDir($dir_name){
		checkFileExist($this->main.$dir_name);
		removeAllDirectory($this->main.$dir_name);
	}
	/* ! ---------- createList ---------- ---------- ---------- ---------- */
	function createList(){
		$dir = opendir($this->main);
		while( $file_name = readdir( $dir ) ){
			if (substr($file_name, 0,1) !=".") {
				if(is_dir($this->main.$file_name)){
					//echo($file_name."\n");
					array_push($this->dirs,$file_name);
				} else{
					//echo("---".$file_name."\n");
					$s = changeExtentionLower($this->main,$file_name);
					array_push($this->files,$s);
				}
			}
		}
		closedir($dir);
	}
	/* ! ---------- createInfoJSON ---------- ---------- ---------- ---------- */
	function createInfoJSON(){
		$json = array();
		$dirs = $this->dirs;
		for ($i = 0 ; $i < count($dirs); $i++) {
			$s = '{ ';
			$s .= '"name":"'.$dirs[$i].'", ';
			$s .= '"filecount":"'.$this->getOwnFileCount($this->main.$dirs[$i]).'",';
			$s .= '"filesize":"",';
			$s .= '"filemtime":""';
			$s .= '}';
			array_push($json,$s);
		}
		return join(",",$json);
	}
	function getOwnFileCount($dir){
		$c = 0;
		$filelist=scandir($dir);			
		for ($i = 0 ; $i < count($filelist); $i++) {
			if(is_imageFileName($filelist[$i])){
				$c++;
			}
		}
		return $c;
	}
}


/* ! ---------- ImageFileClass ---------- ---------- ---------- ---------- */

class ImageFileClass{

	var $name = "";
	var $main = "";
	var $mini = "";
	var $orig = "";
	var $json = "";
	var $preview = "";
	
	var $re_name = "";
	var $re_main = "";
	var $re_mini = "";
	var $re_orig = "";
	var $re_json = "";
	
	function init($_base,$_name){
		$this->name 	= $_name;
		$this->main 	= $_base->main.$_name;
		$this->mini 	= $_base->mini.$_name;
		$this->orig 	= $_base->orig.$_name;
		$this->json 	= $_base->json.$_name.".json";
		$this->preview 	= IMAGE_DIR.$_name;
	}
	function init_re($_base,$_name){
		$this->re_name 	= $_name;
		$this->re_main 	= $_base->main.$_name;
		$this->re_mini 	= $_base->mini.$_name;
		$this->re_orig 	= $_base->orig.$_name;
		$this->re_json 	= $_base->json.$_name.".json";
	}
	function createCopyImages(){
		if(file_exists($this->main)){
			if($this->checkSize($this->main,IMAGE_SIZE_DEF)){
			    $thumbImage = $this->resize($this->main,IMAGE_SIZE_DEF);
				unlink($this->main);
				if(strrpos($this->main, ".png")){
			       imagepng($thumbImage, $this->main);
				}else{
			       imagejpeg($thumbImage, $this->main);
			    }
		    }
			$this->createCopyImages_Mini($this->main,false);
			if(strrpos($this->main, ".png")){
				$this->createCopyImages_PNG($this->main,$this->orig);
			}else{
				$this->createCopyImages_JPG($this->main,$this->orig);
			}
			$this->createJSON($this->json);
		}
	}
	
	function checkSize($_original,$_w){
		$imagesize = getimagesize($_original);
		$width = $imagesize[0];
		$height = $imagesize[1];
		$b = false;
		if($width > $_w){
			$b  = true;
		}
		if($height > $_w){
			$b  = true;
		}
		return $b;
	}
	function resize($_original,$_w){
		$imagesize = getimagesize($_original);
		$width = $imagesize[0];
		$height = $imagesize[1];
		if(strrpos($this->main, ".png")){
			$srcImage = ImageCreateFromPng($_original);
		}else{
			$srcImage = ImageCreateFromJpeg($_original);
		}
		$W = $_w;//$this->miniW;
		
		if($width > $height){
			$thumbW = $W;
			$thumbH = round($height/$width*$W);
		} else{
			$thumbW = round($width/$height*$W);
			$thumbH = $W;
		}
		
		$thumbImage = ImageCreateTrueColor($thumbW, $thumbH);
		ImageFill($thumbImage , 0 , 0 , 0xFFFFFF);
		ImageCopyResampled($thumbImage, $srcImage, 0, 0, 0, 0, $thumbW, $thumbH, $width, $height);
	   return $thumbImage;
	}
	function createCopyImages_Mini($_original,$_isOverRide){
		$b = false;
		$_copy = $this->mini;
		if(!file_exists($_copy)){$b = true;}
		if($_isOverRide){$b = true;}
		
		if($b){
			if(file_exists($_copy)){
				unlink($_copy);
			};
		    $thumbImage = $this->resize($_original,IMAGE_SIZE_MINI);
			if(strrpos($this->main, ".png")){
		       imagepng($thumbImage, $_copy);
			}else{
		       imagejpeg($thumbImage, $_copy);
		    }
		}
	}
	function createCopyImages_PNG($_original,$_copy){
		if(!file_exists($_copy)){
			imagepng(ImageCreateFromPng($_original), $_copy);
		}
	}
	function createCopyImages_JPG($_original,$_copy){
		if(!file_exists($_copy)){
			imagejpeg(ImageCreateFromJpeg($_original), $_copy);
		}
	}
	function createJSON($_original){
		if(! file_exists($_original)){
			file_put_contents($_original, "{}");
		}
	}
	
	function createInfoJSON(){
		$s = "";
		$s .= '{ ';
		$s .= '"name":"'.$this->name .'", ';
		$s .= '"filesize":"'.filesize($this->main) .'", ';
		$s .= '"filemtime":"'.date ("Y/m/d H:i:s", filemtime($this->main)).'"';
		$s .= '}';
		return $s;
	}
	
	function upload($tempImage){
		if(!is_imageFileName($this->main)){
			status_error("this is not image file.");
		}
		if ($_FILES['image']['error'] != UPLOAD_ERR_OK) {
			status_error("failed to upload image.");
		}
		if(! move_uploaded_file($tempImage, $this->main)){
			status_error("failed to upload image.");
		}
	}
	function previewImage($tempImage){
		if(isset($tempImage)){
			move_uploaded_file($tempImage, $this->preview);
		} else{
			status_error("failed to upload image.");
		}
	}
	function publicImage($tempImage){
		if(!is_imageFileName($this->main)){
			status_error("this is not image file.");
		}
		if(isset($tempImage)){
			move_uploaded_file($tempImage, $this->main);
			$this->createCopyImages_Mini($this->main,true);
		} else{
			status_error("failed to upload image.");
		}
		
		if(isset($_POST["json"])){
			$this->writeJSON($this->json,$_POST["json"]);
		}
	}
	function updateJson(){
		if(isset($_POST["json"])){
			$this->writeJSON($this->json,$_POST["json"]);
		}
	}
	function writeJSON($f,$t){
		if(file_exists($f)){
			if(!is_writable($f)){
				unlink($f);
			}
		}
		if(file_put_contents($f, $t)){
			//
		} else {
			status_error("failed to write JSON.");
		}
	}
	
	/* ! ---------- rename ---------- ---------- ---------- ---------- */
	
	function rename(){
		checkFileExist($this->main);
		if(! rename($this->main,$this->re_main) ){
			status_error("failed to rename file.");
		} 
		$this->rename_core($this->mini,$this->re_mini);
		$this->rename_core($this->orig,$this->re_orig);
		$this->rename_core($this->json,$this->re_json);
		
		if(file_exists($this->re_json)){
			$text = file_get_contents($this->re_json);
			$rep = str_replace("/".$this->name, "/".$this->re_name, $text);
			$this->writeJSON($this->re_json,$rep);
		}
	}
	
	function rename_core($f1,$f2){
		if(file_exists($f1)){ rename($f1,$f2);}
	}
	
	/* ! ---------- duplicate ---------- ---------- ---------- ---------- */
	
	function duplicate(){
		checkFileExist($this->main);
		if(! copy($this->main,$this->re_main) ){
			status_error("failed to copy file.");
		} 
		$this->duplicate_core($this->mini,$this->re_mini);
		$this->duplicate_core($this->orig,$this->re_orig);
		$this->duplicate_core($this->json,$this->re_json);
		
		if(file_exists($this->re_json)){
			$text = file_get_contents($this->re_json);
			$rep = str_replace("/".$this->name, "/".$this->re_name, $text);
			$this->writeJSON($this->re_json,$rep);
		}
	}
	
	function duplicate_core($f1,$f2){
		if(file_exists($f1)){ copy($f1,$f2); }
	}
	
	/* ! ---------- delete ---------- ---------- ---------- ---------- */
	
	function delete(){
		checkFileExist($this->main);
		if(! unlink($this->main)){
			status_error("failed to delete file.");
		} 
		$this->delete_core($this->mini);
		$this->delete_core($this->orig);
		$this->delete_core($this->json);
	}
	function delete_core($f){
		if(file_exists($f)){ unlink($f);}
	}
}

